This directory contains an example project using CMake and TPIE.

It assumes you have installed TPIE on your local system, for instance using the
deb packages provided for download on the TPIE homepage.
